"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useDidMount = useDidMount;
const react_1 = require("react");
const react_cool_hooks_1 = require("react-cool-hooks");
const rxjs_1 = require("rxjs");
/**
 * @summary Provides an observable for lifecycle hook "componentDidMount"
 * Creates memoized observable that emits only once after component did mount.
 * Replays for each new subscriber while component lifecycle, completes before component will unmount.
 */
function useDidMount() {
    const subject = (0, react_cool_hooks_1.useOnce)(() => new rxjs_1.ReplaySubject(1));
    (0, react_1.useEffect)(() => {
        subject.next();
        return () => subject.complete();
    }, []);
    return (0, react_cool_hooks_1.useOnce)(() => subject.asObservable());
}
//# sourceMappingURL=useDidMount.js.map