"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRxEvent = useRxEvent;
const rxjs_1 = require("rxjs");
const value_guards_1 = require("value-guards");
const react_cool_hooks_1 = require("react-cool-hooks");
const useSubject_1 = require("./useSubject");
/**
 * @summary Provides memoized observable and memoized event listener callback.
 * Completes when component will unmount.
 */
function useRxEvent(...args) {
    const eventSubject = (0, useSubject_1.useSubject)(() => new rxjs_1.Subject());
    const mapFn = (0, react_cool_hooks_1.useFunction)((event) => {
        return (0, value_guards_1.isNonEmptyArray)(args) ? args[0](event) : event;
    });
    const event$ = (0, react_cool_hooks_1.useOnce)(() => eventSubject.pipe((0, rxjs_1.map)(mapFn)));
    const onEvent = (0, react_cool_hooks_1.useFunction)((event) => eventSubject.next(event));
    return [event$, onEvent];
}
//# sourceMappingURL=useRxEvent.js.map