"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useRxRef = useRxRef;
const react_cool_hooks_1 = require("react-cool-hooks");
const rxjs_1 = require("rxjs");
const value_guards_1 = require("value-guards");
const useSubject_1 = require("./useSubject");
const TEAR_DOWN_VALUE = Symbol('TEAR_DOWN_VALUE');
function useRxRef(...args) {
    const refSubject = (0, useSubject_1.useSubject)(() => {
        return (0, value_guards_1.isNonEmptyArray)(args)
            ? new rxjs_1.BehaviorSubject(args[0])
            : new rxjs_1.ReplaySubject(1);
    });
    const ref$ = (0, react_cool_hooks_1.useOnce)(() => refSubject.pipe((0, rxjs_1.distinctUntilChanged)(), (0, rxjs_1.switchMap)((refValue) => isCorrectRefValue(refValue) ? (0, rxjs_1.of)(refValue) : rxjs_1.NEVER)));
    const ref = (0, react_cool_hooks_1.useOnce)(() => createComboRef(refSubject, args[0]));
    return [ref$, ref];
}
function createComboRef(subject, initialValue) {
    let currentValue = initialValue;
    return Object.defineProperty(((newValue) => {
        subject.next(currentValue = newValue);
        return () => subject.next(TEAR_DOWN_VALUE);
    }), 'current', {
        enumerable: true,
        get() {
            return currentValue ?? undefined;
        },
        set(newValue) {
            this(newValue);
        },
    });
}
function isCorrectRefValue(value) {
    return (0, value_guards_1.isDefined)(value) && value !== TEAR_DOWN_VALUE;
}
//# sourceMappingURL=useRxRef.js.map