"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useSubscription = useSubscription;
const react_cool_hooks_1 = require("react-cool-hooks");
const rxjs_1 = require("rxjs");
const useDidMount_1 = require("./useDidMount");
const useWillUnmount_1 = require("./useWillUnmount");
const value_guards_1 = require("value-guards");
const useValueChange_1 = require("./useValueChange");
function useSubscription(...args) {
    if (isMultiUse(args)) {
        return multiUseHook(...args);
    }
    else if (isOnceUse(args)) {
        return onceUseHook(...args);
    }
}
function isMultiUse(args) {
    return (args.length >= 2 && args.length <= 3)
        && args[0] instanceof rxjs_1.Observable
        && (0, value_guards_1.isFunction)(args[1])
        && (args[2] === undefined || (0, value_guards_1.isNonEmptyRecord)(args[2]));
}
function isOnceUse(args) {
    return (args.length >= 1 && args.length <= 2)
        && (0, value_guards_1.isFunction)(args[0])
        && (args[1] === undefined || (0, value_guards_1.isNonEmptyRecord)(args[1]));
}
function multiUseHook(observable, callback, config) {
    const didMount$ = (0, useDidMount_1.useDidMount)();
    const willUnmount$ = (0, useWillUnmount_1.useWillUnmount)();
    const source$ = (0, useValueChange_1.useValueChange)(observable);
    const wrappedCallback = (0, react_cool_hooks_1.useFunction)(callback);
    const toSubObservable = (0, react_cool_hooks_1.useFunction)((sourceObservable) => new rxjs_1.Observable(() => {
        const sub = wrappedCallback(sourceObservable);
        return () => sub.unsubscribe();
    }));
    (0, react_cool_hooks_1.useOnce)(() => {
        (config?.immediate ? (0, rxjs_1.of)(undefined) : didMount$)
            .pipe((0, rxjs_1.switchMap)(() => source$), (0, rxjs_1.switchMap)(toSubObservable), (0, rxjs_1.takeUntil)(willUnmount$))
            .subscribe();
    });
}
function onceUseHook(callback, config) {
    const didMount$ = (0, useDidMount_1.useDidMount)();
    const willUnmount$ = (0, useWillUnmount_1.useWillUnmount)();
    const wrappedCallback = (0, react_cool_hooks_1.useFunction)(callback);
    const toSubObservable = (0, react_cool_hooks_1.useFunction)(() => new rxjs_1.Observable(() => {
        const sub = wrappedCallback();
        return () => sub.unsubscribe();
    }));
    (0, react_cool_hooks_1.useOnce)(() => {
        (config?.immediate ? (0, rxjs_1.of)(undefined) : didMount$)
            .pipe((0, rxjs_1.switchMap)(toSubObservable), (0, rxjs_1.takeUntil)(willUnmount$))
            .subscribe();
    });
}
//# sourceMappingURL=useSubscription.js.map