"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useValueChange = useValueChange;
const react_1 = require("react");
const react_cool_hooks_1 = require("react-cool-hooks");
const rxjs_1 = require("rxjs");
const useSubject_1 = require("./useSubject");
/**
 * @summary Provides memoized observable for passed value.
 * Emits new values when passed value changes. Completes when component will unmount
 */
function useValueChange(value) {
    const valueSubject = (0, useSubject_1.useSubject)(() => new rxjs_1.BehaviorSubject(value));
    const value$ = (0, react_cool_hooks_1.useOnce)(() => valueSubject.pipe((0, rxjs_1.distinctUntilChanged)()));
    (0, react_1.useEffect)(() => {
        valueSubject.next(value);
    }, [value]);
    return value$;
}
//# sourceMappingURL=useValueChange.js.map