"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.multicastForUI = multicastForUI;
const rxjs_1 = require("rxjs");
const value_guards_1 = require("value-guards");
function multicastForUI(...args) {
    if (isFactoryUsage(args)) {
        return args[0].pipe((0, rxjs_1.share)({
            resetOnComplete: false,
            resetOnRefCountZero: false,
            connector: () => {
                return isInitialValuePassedIntoFactory(args)
                    ? new rxjs_1.BehaviorSubject(args[1])
                    : new rxjs_1.ReplaySubject(1);
            },
        }));
    }
    if (isOperatorUsage(args)) {
        return (0, rxjs_1.pipe)((0, rxjs_1.share)({
            resetOnComplete: false,
            resetOnRefCountZero: false,
            connector: () => {
                return (0, value_guards_1.isNonEmptyArray)(args) ? new rxjs_1.BehaviorSubject(args[0]) : new rxjs_1.ReplaySubject(1);
            },
        }));
    }
    throw new Error(`multicastForUI: Unknown list of arguments.\n${args.join('\n')}`);
}
function isFactoryUsage(args) {
    return args.length <= 2 && args[0] instanceof rxjs_1.Observable;
}
function isOperatorUsage(args) {
    return !isFactoryUsage(args);
}
function isInitialValuePassedIntoFactory(args) {
    return args.length > 1;
}
//# sourceMappingURL=multicastForUI.js.map