import { useState } from 'react';
import { useOnce } from 'react-cool-hooks';
import { _isObservableArgument, _isObservableFactoryArgument, _useObservableInternals } from '../internal';
export function useObservable(...args) {
    if (_isObservableArgument(args)) {
        return observableHook(...args);
    }
    if (_isObservableFactoryArgument(args)) {
        return observableFactoryHook(...args);
    }
    return undefined;
}
function observableHook(observable) {
    const internalStateRef = _useObservableInternals(observable, (newValue, callback) => {
        setValue(newValue);
        callback();
    });
    const [internalValue, setValue] = useState(internalStateRef.valueCache);
    if (internalStateRef.valuesBuffer.size > 0) {
        return internalStateRef.valuesBuffer.dissolve();
    }
    return internalStateRef.reactStateUsed ? internalValue : internalStateRef.valueCache;
}
function observableFactoryHook(observableFactory) {
    const observable = useOnce(observableFactory);
    return observableHook(observable);
}
//# sourceMappingURL=useObservable.js.map