import { map, Subject } from 'rxjs';
import { isNonEmptyArray } from 'value-guards';
import { useFunction, useOnce } from 'react-cool-hooks';
import { useSubject } from './useSubject';
/**
 * @summary Provides memoized observable and memoized event listener callback.
 * Completes when component will unmount.
 */
export function useRxEvent(...args) {
    const eventSubject = useSubject(() => new Subject());
    const mapFn = useFunction((event) => {
        return isNonEmptyArray(args) ? args[0](event) : event;
    });
    const event$ = useOnce(() => eventSubject.pipe(map(mapFn)));
    const onEvent = useFunction((event) => eventSubject.next(event));
    return [event$, onEvent];
}
//# sourceMappingURL=useRxEvent.js.map