import { useOnce } from 'react-cool-hooks';
import { BehaviorSubject, distinctUntilChanged, NEVER, of, ReplaySubject, switchMap } from 'rxjs';
import { isDefined, isNonEmptyArray } from 'value-guards';
import { useSubject } from './useSubject';
const TEAR_DOWN_VALUE = Symbol('TEAR_DOWN_VALUE');
export function useRxRef(...args) {
    const refSubject = useSubject(() => {
        return isNonEmptyArray(args)
            ? new BehaviorSubject(args[0])
            : new ReplaySubject(1);
    });
    const ref$ = useOnce(() => refSubject.pipe(distinctUntilChanged(), switchMap((refValue) => isCorrectRefValue(refValue) ? of(refValue) : NEVER)));
    const ref = useOnce(() => createComboRef(refSubject, args[0]));
    return [ref$, ref];
}
function createComboRef(subject, initialValue) {
    let currentValue = initialValue;
    return Object.defineProperty(((newValue) => {
        subject.next(currentValue = newValue);
        return () => subject.next(TEAR_DOWN_VALUE);
    }), 'current', {
        enumerable: true,
        get() {
            return currentValue ?? undefined;
        },
        set(newValue) {
            this(newValue);
        },
    });
}
function isCorrectRefValue(value) {
    return isDefined(value) && value !== TEAR_DOWN_VALUE;
}
//# sourceMappingURL=useRxRef.js.map