import { useFunction, useOnce } from 'react-cool-hooks';
import { Observable, of, switchMap, takeUntil } from 'rxjs';
import { useDidMount } from './useDidMount';
import { useWillUnmount } from './useWillUnmount';
import { isFunction, isNonEmptyRecord } from 'value-guards';
import { useValueChange } from './useValueChange';
export function useSubscription(...args) {
    if (isMultiUse(args)) {
        return multiUseHook(...args);
    }
    else if (isOnceUse(args)) {
        return onceUseHook(...args);
    }
}
function isMultiUse(args) {
    return (args.length >= 2 && args.length <= 3)
        && args[0] instanceof Observable
        && isFunction(args[1])
        && (args[2] === undefined || isNonEmptyRecord(args[2]));
}
function isOnceUse(args) {
    return (args.length >= 1 && args.length <= 2)
        && isFunction(args[0])
        && (args[1] === undefined || isNonEmptyRecord(args[1]));
}
function multiUseHook(observable, callback, config) {
    const didMount$ = useDidMount();
    const willUnmount$ = useWillUnmount();
    const source$ = useValueChange(observable);
    const wrappedCallback = useFunction(callback);
    const toSubObservable = useFunction((sourceObservable) => new Observable(() => {
        const sub = wrappedCallback(sourceObservable);
        return () => sub.unsubscribe();
    }));
    useOnce(() => {
        (config?.immediate ? of(undefined) : didMount$)
            .pipe(switchMap(() => source$), switchMap(toSubObservable), takeUntil(willUnmount$))
            .subscribe();
    });
}
function onceUseHook(callback, config) {
    const didMount$ = useDidMount();
    const willUnmount$ = useWillUnmount();
    const wrappedCallback = useFunction(callback);
    const toSubObservable = useFunction(() => new Observable(() => {
        const sub = wrappedCallback();
        return () => sub.unsubscribe();
    }));
    useOnce(() => {
        (config?.immediate ? of(undefined) : didMount$)
            .pipe(switchMap(toSubObservable), takeUntil(willUnmount$))
            .subscribe();
    });
}
//# sourceMappingURL=useSubscription.js.map