import { _isObservableArgument, _isObservableFactoryArgument, _useObservableInternals } from '../internal';
import { useOnce } from 'react-cool-hooks';
import { useState, useTransition } from 'react';
export function useTransitionObservable(...args) {
    if (_isObservableArgument(args)) {
        return observableHook(...args);
    }
    if (_isObservableFactoryArgument(args)) {
        return observableFactoryHook(...args);
    }
    return [false, undefined];
}
function observableHook(observable) {
    const [pending, startTransition] = useTransition();
    const internalStateRef = _useObservableInternals(observable, (newValue, callback) => {
        startTransition(() => {
            setValue(newValue);
            callback();
        });
    });
    const [internalValue, setValue] = useState(internalStateRef.valueCache);
    if (internalStateRef.valuesBuffer.size > 0) {
        return [pending, internalStateRef.valuesBuffer.dissolve()];
    }
    return [
        pending,
        internalStateRef.reactStateUsed ? internalValue : internalStateRef.valueCache
    ];
}
function observableFactoryHook(observableFactory) {
    const observable = useOnce(observableFactory);
    return observableHook(observable);
}
//# sourceMappingURL=useTransitionObservable.js.map