import { useOnce, useUnmountEffect } from 'react-cool-hooks';
import { Subject } from 'rxjs';
/**
 * @summary Provides an observable for lifecycle hook "componentWillUnmount"
 * Creates memoized observable that emits only once and completes before component will unmount.
 */
export function useWillUnmount() {
    const subject = useOnce(() => new Subject());
    useUnmountEffect(() => {
        subject.next();
        subject.complete();
    });
    return useOnce(() => subject.asObservable());
}
//# sourceMappingURL=useWillUnmount.js.map