import { distinctUntilChanged, filter, map, mergeWith } from 'rxjs';
import { useDidMount } from '../hooks/useDidMount';
import { useFunction, useOnce } from 'react-cool-hooks';
import { Queue } from './Queue';
import { useSubscription } from '../hooks/useSubscription';
export function _useObservableInternals(observable, setStateFn) {
    const didMount$ = useDidMount();
    const internalStateRef = useOnce(() => ({
        didMount: false,
        valuesBuffer: new Queue(),
        valueCache: undefined,
        reactStateUsed: false,
    }));
    const updateState = useFunction((newValue) => {
        if (internalStateRef.didMount) {
            setStateFn(newValue, () => {
                internalStateRef.valueCache = newValue;
                internalStateRef.reactStateUsed = true;
            });
        }
        else {
            internalStateRef.valuesBuffer.push(newValue);
            internalStateRef.valueCache = newValue;
        }
    });
    useSubscription(() => (didMount$.subscribe(() => {
        internalStateRef.didMount = true;
    })), { immediate: true });
    useSubscription(observable, (currentObservable) => (currentObservable
        .pipe(distinctUntilChanged(), mergeWith(didMount$.pipe(map(() => internalStateRef.valuesBuffer), filter((valuesBuffer) => valuesBuffer.size > 0), map((valuesBuffer) => valuesBuffer.dissolve()))))
        .subscribe((newValue) => {
        updateState(newValue);
    })), { immediate: true });
    return internalStateRef;
}
//# sourceMappingURL=_useObservableInternals.js.map