import { BehaviorSubject, Observable, pipe, ReplaySubject, share } from 'rxjs';
import { isNonEmptyArray } from 'value-guards';
export function multicastForUI(...args) {
    if (isFactoryUsage(args)) {
        return args[0].pipe(share({
            resetOnComplete: false,
            resetOnRefCountZero: false,
            connector: () => {
                return isInitialValuePassedIntoFactory(args)
                    ? new BehaviorSubject(args[1])
                    : new ReplaySubject(1);
            },
        }));
    }
    if (isOperatorUsage(args)) {
        return pipe(share({
            resetOnComplete: false,
            resetOnRefCountZero: false,
            connector: () => {
                return isNonEmptyArray(args) ? new BehaviorSubject(args[0]) : new ReplaySubject(1);
            },
        }));
    }
    throw new Error(`multicastForUI: Unknown list of arguments.\n${args.join('\n')}`);
}
function isFactoryUsage(args) {
    return args.length <= 2 && args[0] instanceof Observable;
}
function isOperatorUsage(args) {
    return !isFactoryUsage(args);
}
function isInitialValuePassedIntoFactory(args) {
    return args.length > 1;
}
//# sourceMappingURL=multicastForUI.js.map